﻿//*************************************************************************************************
//【サンプルプログラム】『Kinect拡張現実楽器演奏システム』
//【名称】KinectMusicSystem　　【Version】0.36
//【作成者】私設研究所Neo-Tech-Lab.com  上田智章
//【作成日】2012年3月5日　【コメント追記】2012年10月20日
//【注意事項】
//*************************************************************************************************
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Diagnostics;                   //【Debug】
using System.Drawing;                       //【Bitmap】【Color】
using System.Drawing.Imaging;               //【BitmapData】
using System.Runtime.InteropServices;       //【Marshal.Copy】
using Microsoft.Kinect;                     //【参照設定】プロジェクト(P)⇒参照の追加(F)⇒.NETタブ⇒Microsoft.Kinectを選択
using Microsoft.DirectX.AudioVideoPlayback; //【AudioVideoPlayback】

namespace Kinect_MusicSystemLite
{
    public partial class Form1 : Form
    {
        //【KINECT関連】
        //　関数内でダイナミックに変数を確保すると動作速度が遅くなるので、ここにまとめて変数を確保しています。
        private KinectSensor KS_KinectSensor;   //【KINECT】
        private DepthImageFrame KS_DepthFrame;  //【KINECTのDepthImageFrame】
        private short[] NTL_DepthData;          //【比較用のDepth値】
        private short[] KS_DepthData;           //【KINECTのDepthImageData】16bit/画素(MSB13bit:Depth, LSB3bit:PlayerID) 
        private byte[] KS_DepthImageDataXRGB;   //【KINECTのDepthImageData】32bit/画素,X8R8G8B8表示形式
        private int KS_DepthFrameWidth;         //【KINECTのDepthFrameの横方向画素数】
        private int KS_DepthFrameHeight;        //【KINECTのDepthFrameの縦方向画素数】
        private Bitmap KS_bmp2;                 //【DepthImage表示用Bitmapオブジェクト】
        private BitmapData KS_data2;            //【DepthImage用BitmapData】
        private Rectangle KS_rect2;             //【DepthImage表示枠】
        private int KS_PlayerIndexBitmask;      //【DepthデータのPlayer情報】 0000 0000 0000 0111B = 7
        private int KS_PlayerIndexBitmaskWidth; //【DepthデータのPlayer情報】 3 bits
        private int KS_Lmin;                    //【深度測定可能最近距離】default:  800mm, near: 400mm 
        private int KS_Lmax;                    //【深度測定可能最遠距離】default: 4000mm, near:3000mm
        private bool KS_flagFlip = false;       //【左右反転フラグ】
        //【NTL拡張現実センサ関連】---------------------------------------------------------
        private NTL_ColorBar ColorBar = new NTL_ColorBar(); //【デプス値をカラーに変換する部品】
        private Audio[] Drum = new Audio[20];
        private string DrumSound1 = "../../DataDrums/Drum_";
        private string[] DrumSound2 = {"01","02","03","04","05","06","07","08","09","10",
                                       "11","12","13","14","15","16","17","18","19","20"};
        private string DrumSound3 = ".wav";
        private Audio[] Piano = new Audio[100];
        private string PianoSound1 = "../../DataWaves/Wave";
        private string[] PianoSound2 = {"000","001","002","003","004","005","006","007","008","009",
                                        "010","011","012","013","014","015","016","017","018","019",
                                        "020","021","022","023","024","025","026","027","028","029",
                                        "030","031","032","033","034","035","036","037","038","039",
                                        "040","041","042","043","044","045","046","047","048","049",
                                        "050","051","052","053","054","055","056","057","058","059",
                                        "060","061","062","063","064","065","066","067","068","069",
                                        "070","071","072","073","074","075","076","077","078","079",
                                        "080","081","082","083","084","085","086","087","088","089",
                                        "090","091","092","093","094","095","096","097","098","099","100"};  
        private string PianoSound3 = ".wav";

        //【楽器選択条件】
        private int cDrum = 0;                //【キャリブレーション用デプスフレームカウンタ】
        private const int nPixel = 50;        //【50画素以上Depth値が変化したらタッチと判断】
        private const short DepthOffset = 30; //【Dppth値が30以上違えばタッチと判断】
        private const short DepthSpan = 150;  //【許容範囲】
        private Boolean[] cTouch = new Boolean[8]; //【今回の判定結果】
        private Boolean[] pTouch = new Boolean[8]; //【前回の判定結果】
        //                          【x0,  y0,  Lx, Ly】　　　　【ピアノ】【ドラム】     
        private int[] KinectRect = {   5, 205,  30, 30,   //【00】ド　　　クローズドハイハット
                                      45, 205,  30, 30,   //【01】レ　　　スネア
                                      85, 205,  30, 30,   //【02】ミ　　　バスドラ
                                     125, 205,  30, 30,   //【03】ファ  　ハイタム　
                                     165, 205,  30, 30,   //【04】ソ  　　ミッドタム
                                     205, 205,  30, 30,   //【05】ラ  　　ロータム
                                     245, 205,  30, 30,   //【06】シ  　　クラッシュシンバル１　
                                     285, 205,  30, 30 }; //【07】ド  
        private Boolean fPianoSelect = true; 

        public Form1()
        {
            InitializeComponent();
            //***********************************************************
            //【Kinect検出】【共通】
            //***********************************************************
            //【利用可能なKINECTセンサを取得する】
            KS_KinectSensor = (from sensorToCheck
                               in KinectSensor.KinectSensors
                               where sensorToCheck.Status == KinectStatus.Connected
                               select sensorToCheck).FirstOrDefault();
            //【検出結果の表示】
            if (KS_KinectSensor == null) //【Kinect接続が確認できなかった場合】
            {
                pictureBox2.Image = imageList1.Images[1];
                MessageBox.Show(
                   "接続可能なKINECTセンサが見当たりません。",
                   "KINECT for Windows Error Message",
                   MessageBoxButtons.OK
                );
                return;
            }
            else //【Kinect検出に成功】
            {
                pictureBox2.Image = imageList1.Images[0];
            }

            //***********************************************************
            //【Kinectの初期化処理】
            //***********************************************************
            //【KINECTの設定】DepthStreamを許可
            KS_KinectSensor.DepthStream.Enable(DepthImageFormat.Resolution320x240Fps30);    //【DepthStream許可】
            // DepthImageFormatとしては他にResolution320x240Fps30,Resolution640x480Fps30とDepthImageFormat.Resolution80x60Fps30がある
            //【KINECT動作開始】
            KS_KinectSensor.Start(); //【KINECTスタート】

            //【KINECTデータ取得イベントの設定とデータバッファの確保】
            KS_KinectSensor.DepthFrameReady += new EventHandler<DepthImageFrameReadyEventArgs>(DepthImageReady); //【DepthImageReadyをcallするよう設定】
            KS_DepthData = new short[KS_KinectSensor.DepthStream.FramePixelDataLength];             //【深度情報データ１フレーム分を保存するメモリを確保】
            NTL_DepthData = new short[KS_KinectSensor.DepthStream.FramePixelDataLength];
            KS_DepthImageDataXRGB = new byte[KS_KinectSensor.DepthStream.FramePixelDataLength * 4]; //【深度情報データ表示用】

            KS_PlayerIndexBitmask = DepthImageFrame.PlayerIndexBitmask;
            KS_PlayerIndexBitmaskWidth = DepthImageFrame.PlayerIndexBitmaskWidth;
            KS_DepthFrameWidth = KS_KinectSensor.DepthStream.FrameWidth;   //【DepthImageの横方向画素数】
            KS_DepthFrameHeight = KS_KinectSensor.DepthStream.FrameHeight; //【DepthImageの縦方向画素数】
            KS_bmp2 = new Bitmap(KS_DepthFrameWidth, KS_DepthFrameHeight, System.Drawing.Imaging.PixelFormat.Format32bppRgb); //【DepthImage表示用】
            KS_rect2 = new Rectangle(0, 0, KS_DepthFrameWidth, KS_DepthFrameHeight); //【DepthImage用枠】
         // KS_KinectSensor.DepthStream.Range = DepthRange.Default; //【Depth測定モードをDefaultに設定】
            KS_KinectSensor.DepthStream.Range = DepthRange.Near;    //【Depth測定モードをNearに設定】
            KS_CheckDistance();                                     //【設定結果を表示】Lmax, Lminを取得
            pictureBox1.SizeMode = PictureBoxSizeMode.StretchImage;

            //【Kinectヘッドの仰角を設定】設定範囲は±27°
            int Angle = -20;
            KS_KinectSensor.ElevationAngle = Angle;
            textBox1.Text = Angle.ToString();

            //【深度情報をカラーに変換する為の準備処理】
            ColorBar.CreateColorPalletForAbsolute(KS_Lmax+1);        //【カラーパレットを作成する】
            pictureBox3.Image = ColorBar.CreateColorScale(600, 10);  //【600×10画素サイズのカラーバーを作成して表示する】

            LoadAudioData(); //【音源データを読込む】

            //【Formを閉じるイベントの設定】
            this.FormClosing += new FormClosingEventHandler(Form1_FormClosing);
            radioButton1.CheckedChanged += new EventHandler(DepthRangeChange);
            checkBox2.CheckedChanged += new EventHandler(checkBox2_CheckedChanged);
        }

        //***************************************************************
        //【終了コントロール】
        //***************************************************************
        void Form1_FormClosing(object sender, FormClosingEventArgs e)
        {
            int i;
            if (KS_KinectSensor != null)
            {
                KS_KinectSensor.Stop();    //【KINECTセンサを終了】★これを実行しないとレーザーが消えない
                KS_KinectSensor.Dispose(); //【KINECTセンサのオブジェクトを解放する】
            }
            for (i = 0; i < 20; i++) { Drum[i].Stop(); Drum[i].Dispose(); Drum[i] = null; }
            for (i = 0; i < 100; i++) { Piano[i].Stop(); Piano[i].Dispose(); Piano[i] = null; }
        }

        //***************************************************************
        //【LoadAudioData】Waveファイルを読み込む
        //***************************************************************
        unsafe private void LoadAudioData()
        {
            int i;
            //【ドラム音源】
            for (i = 0; i < 20; i++) { Drum[i] = new Audio(DrumSound1 + DrumSound2[i] + DrumSound3); }
            //【ピアノ音源】
            for (i = 0; i < 100; i++) { Piano[i] = new Audio(PianoSound1 + PianoSound2[i] + PianoSound3); }
            //【ドラム触チェック】
            for (i = 0; i < cTouch.Length; i++) { cTouch[i] = pTouch[i] = false; }
        }

        //***************************************************************
        //【距離モード変更】Defaultモード(800mm～4000mm) Nearモード(400m～3000mm)
        //***************************************************************
        void DepthRangeChange(object sender, EventArgs e)
        {
            if (radioButton1.Checked) { KS_KinectSensor.DepthStream.Range = DepthRange.Default; label8.Text = "Default"; }
            else { KS_KinectSensor.DepthStream.Range = DepthRange.Near; label12.Text = "Near"; }
            KS_CheckDistance();
        }

        //***************************************************************
        //【CheckDistance】KINECTセンサの検出可能距離現在値を調べる
        //***************************************************************
        private void KS_CheckDistance()
        {
            KS_Lmax = KS_KinectSensor.DepthStream.MaxDepth;
            KS_Lmin = KS_KinectSensor.DepthStream.MinDepth;
            label1.Text = "Min=" + KS_Lmin.ToString() + "mm";
            label2.Text = "Max=" + KS_Lmax.ToString() + "mm";
        }

        //***************************************************************
        //【上下角変更ボタン】KINECTの上下角を変更。±27°の範囲内。時間を置かないとエラーが発生する
        //***************************************************************
        private void button2_Click(object sender, EventArgs e)
        {
            Int32 angle = int.Parse(textBox1.Text); //【設定角度を読み込む】±27°
            if (angle <= KS_KinectSensor.MaxElevationAngle && angle >= KS_KinectSensor.MinElevationAngle)
            {
                KS_KinectSensor.ElevationAngle = angle; //【上下角の変更】
            }
        }

        //***************************************************************
        //【カラー画像の左右反転指定フラグ】
        //***************************************************************
        private void checkBox1_CheckedChanged(object sender, EventArgs e)
        {
            if (checkBox1.Checked) { KS_flagFlip = true; } else { KS_flagFlip = false; }
        }

        //***************************************************************
        //【楽器選択】
        //***************************************************************
        void checkBox2_CheckedChanged(object sender, EventArgs e)
        {
            if (checkBox2.Checked) { fPianoSelect = true; } else { fPianoSelect = false; }
        }

        //***************************************************************
        //【DepthImageの取得イベント】
        //***************************************************************
        private void DepthImageReady(object sender, DepthImageFrameReadyEventArgs e)
        {
            int i, ix0, iy0, iLx, iLy;

            using (KS_DepthFrame = e.OpenDepthImageFrame())
            {
                if (KS_DepthFrame != null)
                {
                    KS_DepthFrame.CopyPixelDataTo(KS_DepthData); //【KINECTのDepth情報を配列DepthDataにコピー】
                    KS_ConvertDepthToColor(); //【深度情報をカラーバーの色を使って表示形式をX8R8G8B8形式に変換】
                    if (cDrum >= 8)
                    {
                        checkTouchDrum(); //【ドラムチェック】
                        PlayAudioSound(); // PlayDrums();
                    }
                    else
                    {
                        cDrum++;
                        if (cDrum == 1)
                        {
                            for (i = 0; i < KS_DepthData.Length; i++) { NTL_DepthData[i] = (short)((KS_DepthData[i]>>3) & 0x1FFF); }
                        }
                        else
                        {
                            for (i = 0; i < KS_DepthData.Length; i++) { NTL_DepthData[i] += (short)((KS_DepthData[i]>>3) & 0x1FFF); }
                        }
                        if (cDrum == 8)
                        {
                            for (i = 0; i < KS_DepthData.Length; i++) { NTL_DepthData[i] = (short)((NTL_DepthData[i] >> 3) - DepthOffset); }
                        }
                    }
                    KS_data2 = KS_bmp2.LockBits(KS_rect2, ImageLockMode.WriteOnly, System.Drawing.Imaging.PixelFormat.Format32bppRgb); //【Lockする】
                    Marshal.Copy(KS_DepthImageDataXRGB, 0, KS_data2.Scan0, KS_DepthImageDataXRGB.Length); //【UnmanagedMemoryのBitmapDataに配列depthDataをコピーする】
                    KS_bmp2.UnlockBits(KS_data2); //【Lock解除】
                    if (KS_flagFlip) { KS_bmp2.RotateFlip(RotateFlipType.Rotate180FlipY); } //【左右反転】
                    pictureBox1.Image = KS_bmp2;  //【pictureBox1に画像表示】


                    Graphics g = Graphics.FromImage(pictureBox1.Image);
                    Color lc = Color.Azure;
                    SolidBrush newbrush = new SolidBrush(Color.Violet);
                    for (i = 0; i < cTouch.Length; i++)
                    {
                        ix0 = KinectRect[i * 4];
                        iy0 = KinectRect[i * 4 + 1];
                        iLx = KinectRect[i * 4 + 2];
                        iLy = KinectRect[i * 4 + 3];
                        if (KS_flagFlip) { ix0 = 320 - ix0 - iLx; }
                        if (cTouch[i]) { g.FillEllipse(newbrush, ix0 + 2, iy0 + 2, iLx - 4, iLy - 4); }
                        g.DrawRectangle(new Pen(lc), ix0, iy0, iLx, iLy);
                    }
                    g.Dispose();
                    Validate();

                    for (i = 0; i < cTouch.Length; i++) { pTouch[i] = cTouch[i]; }
                }
                else
                {
                    //【DepthFrameがnullだったのは要求が間に合わなかったと考えられます】
                }
            }
        }

        //***************************************************************
        //【ConvertDepthToColor】16ビットのDepth値をカラーバーに対応する色に変更
        //***************************************************************
        private void KS_ConvertDepthToColor()
        {
            int i, j, d;  //【Defaultモード】  800～4000mm
            //  int playerID; //【下位3bitはplayerID】【未使用】
            j = 0;
            for (i = 0; i < KS_DepthData.Length; i++)
            {
                d = KS_DepthData[i]; //【距離情報】【上位13bitがDepth値】【下位3bitはplayerID】【未使用】
                d = ((d >> KS_PlayerIndexBitmaskWidth) & 0x1FFF);  //【realDepth】0mm～8191mm
                if (d < KS_Lmin)  { d = 0; }       //【近すぎる】
                if (d >= KS_Lmax) { d = KS_Lmax; } //【遠すぎる】
                d = d * 4;
                KS_DepthImageDataXRGB[j] = ColorBar.NTL_ColorElement[d]; //【青】B
                KS_DepthImageDataXRGB[j + 1] = ColorBar.NTL_ColorElement[d + 1]; //【緑】G
                KS_DepthImageDataXRGB[j + 2] = ColorBar.NTL_ColorElement[d + 2]; //【赤】R
                KS_DepthImageDataXRGB[j + 3] = ColorBar.NTL_ColorElement[d + 3]; ; //【α】
                j = j + 4;
            }
        }

        //***************************************************************
        //【CheckTouch】Drumに触ったかチェックする
        //***************************************************************
        private void checkTouchDrum()
        {
            int i, jx, jy, k, c;
            int ix0, iy0, iLx, iLy, iDepth;
            for(i=0; i<(int)(KinectRect.Length/4); i++)
            {
                ix0 = KinectRect[4 * i];        //【横位置】
                iy0 = KinectRect[4 * i + 1];    //【縦位置】
                iLx = KinectRect[4 * i + 2];    //【横幅】
                iLy = KinectRect[4 * i + 3];    //【縦幅】
                cTouch[i] = false;
                c = 0;
                for (jy = 0; jy < iLy; jy++)
                {
                    for (jx = 0; jx < iLx; jx++)
                    {
                        k = ix0 + jx + 320 *(iy0 + jy);
                        iDepth = NTL_DepthData[k] - ((KS_DepthData[k] >> 3) & 0x1FFF);
                        if ((iDepth > 0) && (iDepth < DepthSpan))
                        {   //Depthが指定値未満の場合(手前)
                            c++; if (c > nPixel) { cTouch[i] = true; jx = iLx; }
                        }
                    }
                    if (cTouch[i]) { jy = iLy; } //【Check終了】
                }
            }
        }

        //***************************************************************
        //【再度キャリブレーションを行う】
        //***************************************************************
        private void button43_Click(object sender, EventArgs e)
        {
            cDrum = 0;
        }


        //***************************************************************
        //【PlayDrumSound】Drum音源Waveファイルを再生する
        //***************************************************************
        private void PlayAudioSound()
        {
            if (fPianoSelect)
            {
                if ((pTouch[0] == false) && (cTouch[0] == true)) { PlayPianoSound(3); }  //【ド】
                if ((pTouch[1] == false) && (cTouch[1] == true)) { PlayPianoSound(5); }  //【レ】
                if ((pTouch[2] == false) && (cTouch[2] == true)) { PlayPianoSound(7); }  //【ミ】
                if ((pTouch[3] == false) && (cTouch[3] == true)) { PlayPianoSound(8); }  //【ファ】
                if ((pTouch[4] == false) && (cTouch[4] == true)) { PlayPianoSound(10); } //【ソ】
                if ((pTouch[5] == false) && (cTouch[5] == true)) { PlayPianoSound(12); } //【ラ】
                if ((pTouch[6] == false) && (cTouch[6] == true)) { PlayPianoSound(14); } //【シ】
                if ((pTouch[7] == false) && (cTouch[7] == true)) { PlayPianoSound(15); } //【ド】
            }
            else    //【ドラム音】
            {
                if ((pTouch[0] == false) && (cTouch[0] == true)) { PlayDrumSound(9); }  //【42】クローズドハイハット
                if ((pTouch[1] == false) && (cTouch[1] == true)) { PlayDrumSound(1); }  //【38】スネアドラム１
                if ((pTouch[2] == false) && (cTouch[2] == true)) { PlayDrumSound(0); }  //【36】バスドラム
                if ((pTouch[3] == false) && (cTouch[3] == true)) { PlayDrumSound(6); }  //【48】ハイタム２
                if ((pTouch[4] == false) && (cTouch[4] == true)) { PlayDrumSound(4); }  //【45】ミッドタム２
                if ((pTouch[5] == false) && (cTouch[5] == true)) { PlayDrumSound(2); }  //【41】ロータム２
                if ((pTouch[6] == false) && (cTouch[6] == true)) { PlayDrumSound(12); } //【49】クラッシュシンバル１
                if ((pTouch[7] == false) && (cTouch[7] == true)) { PlayDrumSound(17); } //【37】サイドスティック
            }
        }

        private void PlayDrumSound(int i)
        {
            if (Drum[i].Playing == true) { Drum[i].Stop(); }
            Drum[i].Play();
        }

        private void button3_Click(object sender, EventArgs e) { PlayDrumSound(0); }  //【36】バスドラム
        private void button4_Click(object sender, EventArgs e) { PlayDrumSound(1); }  //【38】スネアドラム１
        private void button5_Click(object sender, EventArgs e) { PlayDrumSound(2); }  //【41】ロータム２
        private void button6_Click(object sender, EventArgs e) { PlayDrumSound(3); }  //【43】ロータム１
        private void button7_Click(object sender, EventArgs e) { PlayDrumSound(4); }  //【45】ミッドタム２
        private void button8_Click(object sender, EventArgs e) { PlayDrumSound(5); }  //【47】ミッドタム１
        private void button9_Click(object sender, EventArgs e)  { PlayDrumSound(6); }  //【48】ハイタム２
        private void button10_Click(object sender, EventArgs e) { PlayDrumSound(7); }  //【50】ハイタム１
        private void button11_Click(object sender, EventArgs e) { PlayDrumSound(8); }  //【39】ハンドクラップ
        private void button12_Click(object sender, EventArgs e) { PlayDrumSound(9); }  //【42】クローズドハイハット
        private void button13_Click(object sender, EventArgs e) { PlayDrumSound(10); } //【44】ペダルハイハット
        private void button14_Click(object sender, EventArgs e) { PlayDrumSound(11); } //【46】オープンハイハット
        private void button15_Click(object sender, EventArgs e) { PlayDrumSound(12); } //【49】クラッシュシンバル１
        private void button16_Click(object sender, EventArgs e) { PlayDrumSound(13); } //【51】ライドシンバル１
        private void button17_Click(object sender, EventArgs e) { PlayDrumSound(14); } //【55】スプラッシュシンバル
        private void button18_Click(object sender, EventArgs e) { PlayDrumSound(15); } //【57】クラッシュシンバル２
        private void button19_Click(object sender, EventArgs e) { PlayDrumSound(16); } //【59】ライドシンバル２
        private void button20_Click(object sender, EventArgs e) { PlayDrumSound(17); } //【37】サイドスティック
        private void button21_Click(object sender, EventArgs e) { PlayDrumSound(18); } //【40】スネアドラム２
        private void button22_Click(object sender, EventArgs e) { PlayDrumSound(19); } //【69】カバサ

        private void PlayDrums()
        {
            int i;
            for (i = 0; i < 20; i++)
            {
                if ((pTouch[i] == false) && (cTouch[i] == true)) { PlayDrumSound(i); }
            }

        }

        private void PlayPianoSound(int i)
        {
            int ofs=0;
            if (radioButton3.Checked) ofs = 0;  //オクターブ変更
            if (radioButton4.Checked) ofs = 12;
            if (radioButton5.Checked) ofs = 24;
            if (radioButton6.Checked) ofs = 36;
            if (Piano[i + ofs].Playing == true) { Piano[i + ofs].Stop(); }
            Piano[i+ofs].Play();
        }

        private void button23_Click(object sender, EventArgs e) { PlayPianoSound(0); } //A
        private void button24_Click(object sender, EventArgs e) { PlayPianoSound(1); } //A#
        private void button25_Click(object sender, EventArgs e) { PlayPianoSound(2); } //B
        private void button26_Click(object sender, EventArgs e) { PlayPianoSound(3); } //C   ド
        private void button27_Click(object sender, EventArgs e) { PlayPianoSound(4); } //C#
        private void button28_Click(object sender, EventArgs e) { PlayPianoSound(5); } //D　 レ
        private void button29_Click(object sender, EventArgs e) { PlayPianoSound(6); } //D#
        private void button30_Click(object sender, EventArgs e) { PlayPianoSound(7); } //E　 ミ
        private void button31_Click(object sender, EventArgs e) { PlayPianoSound(8); } //F　 ファ
        private void button32_Click(object sender, EventArgs e) { PlayPianoSound(9); } //F#
        private void button33_Click(object sender, EventArgs e) { PlayPianoSound(10); } //G　ソ
        private void button34_Click(object sender, EventArgs e) { PlayPianoSound(11); } //G#
        private void button35_Click(object sender, EventArgs e) { PlayPianoSound(12); } //A　ラ
        private void button36_Click(object sender, EventArgs e) { PlayPianoSound(13); } //A#
        private void button37_Click(object sender, EventArgs e) { PlayPianoSound(14); } //B　シ
        private void button38_Click(object sender, EventArgs e) { PlayPianoSound(15); } //C　ド
        private void button39_Click(object sender, EventArgs e) { PlayPianoSound(16); } //C#
        private void button40_Click(object sender, EventArgs e) { PlayPianoSound(17); } //D
        private void button41_Click(object sender, EventArgs e) { PlayPianoSound(18); } //D#
        private void button42_Click(object sender, EventArgs e) { PlayPianoSound(19); } //E
    }
}
